design_size library
Enums
Functions
-
getDesignSize(
BuildContext context, {Map< DeviceType, Size> ? customSizes}) → Size - Returns the design size to be used with ScreenUtils package. By default, it will return the following sizes based on DeviceType enum: